@@ -153,16 +153,25 @@ def color(color):
     ----------
     color : int, str
         The colors can be specified by their index, their full name,
-         or the first letter. Available colors are:
+        or the first letter. Available colors are:
 
-        1, ``'b'``: blue
-        2, ``'r'``: red
-        3, ``'y'``: yellow
-        4, ``'p'``: purple
-        5, ``'g'``: green
-        6, ``'t'``: turquois
-        7, ``'o'``: orange
-        8, ``'l'``: light green.
+        +---+---------+-------------+
+        | 1 | ``'b'`` | blue        |
+        +---+---------+-------------+
+        | 2 | ``'r'`` | red         |
+        +---+---------+-------------+
+        | 3 | ``'y'`` | yellow      |
+        +---+---------+-------------+
+        | 4 | ``'p'`` | purple      |
+        +---+---------+-------------+
+        | 5 | ``'g'`` | green       |
+        +---+---------+-------------+
+        | 6 | ``'t'`` | turquois    |
+        +---+---------+-------------+
+        | 7 | ``'o'`` | orange      |
+        +---+---------+-------------+
+        | 8 | ``'l'`` | light green |
+        +---+---------+-------------+
 
     Returns
     -------
@@ -194,13 +203,13 @@ def shortcuts(show=True):
     Parameters
     ----------
     show : bool, optional
-        print the keyboard shortcuts to the default console. The default is
+        Print the keyboard shortcuts to the default console. The default is
         ``True``.
 
     Returns
     -------
     short_cuts : dict
-        dictionary that contains all the shortcuts
+        Dictionary that contains all the shortcuts.
     """  # noqa: W605 (to ignore \*)
     # Note: The end of the docstring can be generated by calling shortcuts()
 
@@ -211,7 +220,7 @@ def shortcuts(show=True):
 
     # print list of short cuts
     if show:
-        # get list of plots that allow toogling axes and colormaps
+        # get list of plots that allow toggling axes and colormaps
         x_toggle = []
         y_toggle = []
         cm_toggle = []
@@ -266,5 +275,8 @@ def shortcuts(show=True):
         print(" ")
         print(f"Toggling the colormap is supported by: {', '.join(cm_toggle)}")
         print(" ")
+        print(("Toggling between line and 2D plots is not supported by:"
+               " spectrogram"))
+        print(" ")
 
     return short_cuts
